Module: Purest
- Defined in:
- lib/purest.rb,
lib/purest/host.rb,
lib/purest/rest.rb,
lib/purest/volume.rb,
lib/purest/host_group.rb,
lib/purest/configuration.rb,
lib/purest/physical_array.rb,
lib/purest/custom_exceptions.rb
Defined Under Namespace
Classes: Configuration, CustomExceptions, Host, HostGroup, PhysicalArray, Rest, Volume
Class Attribute Summary collapse
-
.configuration ⇒ Object
Returns the value of attribute configuration.
-
.lib_path ⇒ Object
Returns the value of attribute lib_path.
-
.root_path ⇒ Object
Returns the value of attribute root_path.
Class Method Summary collapse
-
.configure {|Purest::Configuration| ... } ⇒ Object
Build optional configuration by yielding a block to configure.
-
.require_libs(*libs) ⇒ nil
(also: require_lib)
Internal: Requires internal Faraday libraries.
Class Attribute Details
.configuration ⇒ Object
Returns the value of attribute configuration.
15 16 17 |
# File 'lib/purest.rb', line 15 def configuration @configuration end |
.lib_path ⇒ Object
Returns the value of attribute lib_path.
14 15 16 |
# File 'lib/purest.rb', line 14 def lib_path @lib_path end |
.root_path ⇒ Object
Returns the value of attribute root_path.
13 14 15 |
# File 'lib/purest.rb', line 13 def root_path @root_path end |
Class Method Details
.configure {|Purest::Configuration| ... } ⇒ Object
Build optional configuration by yielding a block to configure
41 42 43 44 |
# File 'lib/purest.rb', line 41 def configure self.configuration ||= Purest::Configuration.new yield(configuration) end |
.require_libs(*libs) ⇒ nil Also known as: require_lib
Internal: Requires internal Faraday libraries.
20 21 22 23 24 |
# File 'lib/purest.rb', line 20 def require_libs(*libs) libs.each do |lib| require "#{lib_path}/#{lib}" end end |